hive-blender.transport.socket

Loopback-only, bounded unframed JSON client; one in-flight call per connection.

Loopback-only, bounded unframed JSON client; one in-flight call per connection.
raw docstring

default-configclj

source

(socket-link config)

Construct a loopback-only link with explicit receive, connect and frame bounds.

Construct a loopback-only link with explicit receive, connect and frame bounds.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries